rm Makefile
rm src/Makefile
/usr/bin/qmake-qt4
make clean
make
